@@ -98,7 +98,7 @@ class AttendanceColumn(object):
         absences = 0
         for meeting in self.meetings:
             journal = ISectionJournal(meeting)
-            if journal.getAbsence(student, meeting, default="") == "n":
+            if journal.isAbsent(student, meeting):
                 absences += 1
         if absences == 0:
             return '<td></td>'
@@ -128,7 +128,7 @@ class AttendanceColumn(object):
         absences = 0
         for meeting in self.meetings:
             journal = ISectionJournal(meeting)
-            if journal.getAbsence(student, meeting, default="") == "n":
+            if journal.isAbsent(student, meeting):
                 absences += 1
 
         name = student.__name__ + "." + self.date.strftime("%Y-%m-%d")
@@ -161,7 +161,7 @@ class AttendanceTotalColumn(object):
         for date, meetings in self.days.items():
             for meeting in meetings:
                 journal = ISectionJournal(meeting)
-                if journal.getAbsence(student, meeting, default="") == "n":
+                if journal.isAbsent(student, meeting):
                     absences += 1
         if absences == 0:
             return '<td></td>'
@@ -184,7 +184,7 @@ class PeriodAttendanceColumn(object):
         absences = []
         for meeting in self.meetings:
             journal = ISectionJournal(meeting)
-            if journal.getAbsence(student, meeting, default="") == "n":
+            if journal.isAbsent(student, meeting):
                 absences.append(meeting)
         if absences == []:
             return '<td></td>'
@@ -199,7 +199,7 @@ class PeriodAttendanceColumn(object):
         absences = []
         for meeting in self.meetings:
             journal = ISectionJournal(meeting)
-            if journal.getAbsence(student, meeting, default="") == "n":
+            if journal.isAbsent(student, meeting):
                 absences.append(meeting)
         if absences == []:
             return '<td></td>'
